==> libxfcegui4-4.1.90.tar.gz: libxfcegui4-4.1.90/libxfcegui4/libxfcegui4.h <==
/* $Id: libxfcegui4.h,v 1.18 2004/08/25 07:09:47 kelnos Exp $ */
/*-
 * Copyright (c) 2002-2004 The Xfce development team.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __LIBXFCEGUI4_LIBXFCEGUI4_H__
#define __LIBXFCEGUI4_LIBXFCEGUI4_H__

#include <libxfcegui4/libxfcegui4-config.h>

#include <libxfcegui4/dialogs.h>
#include <libxfcegui4/gtk_style.h>
#include <libxfcegui4/gtktoxevent.h>
#include <libxfcegui4/icons.h>
#include <libxfcegui4/libnetk.h>
#include <libxfcegui4/preview_filesel.h>
#include <libxfcegui4/session-client.h>
#include <libxfcegui4/xfce-exec.h>
#include <libxfcegui4/xfce_aboutdialog.h>
#include <libxfcegui4/xfce_clock.h>
#include <libxfcegui4/xfce_decorbutton.h>
#include <libxfcegui4/xfce_decortoggle.h>
#include <libxfcegui4/xfce_framebox.h>
#include <libxfcegui4/xfce_iconbutton.h>
#include <libxfcegui4/xfce_menubutton.h>
#include <libxfcegui4/xfce_movehandler.h>
#include <libxfcegui4/xfce_togglebutton.h>
#include <libxfcegui4/xfce_systemtray.h>
#include <libxfcegui4/xfce-appmenuitem.h>
#include <libxfcegui4/xfce-colorbutton.h>
#include <libxfcegui4/xfce-filechooser.h>
#include <libxfcegui4/xfce-gdk-extensions.h>
#include <libxfcegui4/xfce-gtk-extensions.h>
#include <libxfcegui4/xfce-icontheme.h>

#endif  /* !__LIBXFCEGUI4_LIBXFCEGUI4_H__ */

==> libxfcegui4_4.6.4.orig.tar.gz: libxfcegui4-4.6.4/libxfcegui4/libxfcegui4.h <==
/* $Id$ */
/*-
 * Copyright (c) 2002-2006 The Xfce development team.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __LIBXFCEGUI4_LIBXFCEGUI4_H__
#define __LIBXFCEGUI4_LIBXFCEGUI4_H__

#include <libxfcegui4/libxfcegui4-config.h>

#include <libxfcegui4/dialogs.h>
#include <libxfcegui4/gtk_style.h>
#include <libxfcegui4/gtktoxevent.h>
#include <libxfcegui4/icons.h>
#include <libxfcegui4/libnetk.h>
#include <libxfcegui4/preview_filesel.h>
#include <libxfcegui4/session-client.h>
#include <libxfcegui4/xfce-startup-notification.h>
#include <libxfcegui4/xfce-exec.h>
#include <libxfcegui4/xfce_aboutdialog.h>
#include <libxfcegui4/xfce_clock.h>
#include <libxfcegui4/xfce_decorbutton.h>
#include <libxfcegui4/xfce_decortoggle.h>
#include <libxfcegui4/xfce_framebox.h>
#include <libxfcegui4/xfce_iconbutton.h>
#include <libxfcegui4/xfce_menubutton.h>
#include <libxfcegui4/xfce_movehandler.h>
#include <libxfcegui4/xfce_togglebutton.h>
#include <libxfcegui4/xfce_scaled_image.h>
#include <libxfcegui4/xfce_systemtray.h>
#include <libxfcegui4/xfce-appmenuitem.h>
#include <libxfcegui4/xfce-colorbutton.h>
#include <libxfcegui4/xfce-filechooser.h>
#include <libxfcegui4/xfce-gdk-extensions.h>
#include <libxfcegui4/xfce-gtk-extensions.h>
#include <libxfcegui4/xfce-heading.h>
#include <libxfcegui4/xfce-icontheme.h>
#include <libxfcegui4/xfce-titled-dialog.h>
#include <libxfcegui4/xfce-widget-helpers.h>

#endif  /* !__LIBXFCEGUI4_LIBXFCEGUI4_H__ */
